# Organize

Organize tasks @talk-point

## Install

```sh
$ pip3 install shopcloud-organize
```

## Usage

Monatlichen / wöchentliche tasks im Hauptrepo erzeugen

```sh
$ organize tasks list
$ organize tasks create-issues
```
